@@ -13,6 +13,11 @@
 
 #include "XMPCore/source/XMPCore_Impl.hpp"
 #include "XMPCore/source/XMPMeta.hpp"
+#include "XMPCore/source/XMPMeta2.hpp"
+#include "XMPCore/XMPCoreDefines.h"
+#if ENABLE_CPP_DOM_MODEL
+	#include "XMPCore/Interfaces/IMetadata_I.h"
+#endif
 
 #if XMP_WinBuild
 	#pragma warning ( disable : 4101 ) // unreferenced local variable
@@ -76,7 +81,19 @@ WXMPMeta_CTor_1 ( WXMP_Result * wResult )
 {
 	XMP_ENTER_Static ( "WXMPMeta_CTor_1" )	// No lib object yet, use the static entry.
 
-		XMPMeta * xmpObj = new XMPMeta();
+		XMPMeta * xmpObj( NULL );
+        XMP_Bool isCreated = false;
+
+#if ENABLE_CPP_DOM_MODEL
+        if ( sUseNewCoreAPIs ) {
+			 xmpObj = new XMPMeta2();
+             isCreated = true;
+        }
+#endif 
+
+		if(!isCreated)
+			xmpObj = new XMPMeta();
+
 		++xmpObj->clientRefs;
 		XMP_Assert ( xmpObj->clientRefs == 1 );
 		wResult->ptrResult = XMPMetaRef ( xmpObj );
@@ -133,18 +150,6 @@ WXMPMeta_GetGlobalOptions_1 ( WXMP_Result * wResult )
 
 // -------------------------------------------------------------------------------------------------
 
-/* class static */ void
-WXMPMeta_SetGlobalOptions_1 ( XMP_OptionBits options,
-							  WXMP_Result *	 wResult )
-{
-	XMP_ENTER_Static ( "WXMPMeta_SetGlobalOptions_1" )
-
-		XMPMeta::SetGlobalOptions ( options );
-
-	XMP_EXIT
-}
-// -------------------------------------------------------------------------------------------------
-
 /* class static */ void
 WXMPMeta_DumpNamespaces_1 ( XMP_TextOutputProc outProc,
 							void *			   refCon,
@@ -231,21 +236,6 @@ WXMPMeta_GetNamespaceURI_1 ( XMP_StringPtr namespacePrefix,
 	XMP_EXIT
 }
 
-// -------------------------------------------------------------------------------------------------
-
-/* class static */ void
-WXMPMeta_DeleteNamespace_1 ( XMP_StringPtr namespaceURI,
-							 WXMP_Result * wResult )
-{
-	XMP_ENTER_Static ( "WXMPMeta_DeleteNamespace_1" )
-
-		if ( (namespaceURI == 0) || (*namespaceURI == 0) ) XMP_Throw ( "Empty namespace URI", kXMPErr_BadSchema );
-
-		XMPMeta::DeleteNamespace ( namespaceURI );
-
-	XMP_EXIT
-}
-
 // =================================================================================================
 // Class Method Wrappers
 // =====================
@@ -1005,11 +995,56 @@ WXMPMeta_Clone_1 ( XMPMetaRef	  xmpObjRef,
 {
 	XMP_ENTER_ObjRead ( XMPMeta, "WXMPMeta_Clone_1" )
 
-		XMPMeta * xClone = new XMPMeta;	// ! Don't need an output lock, final ref assignment in client glue.
+		XMPMeta * xClone ( NULL );
+        XMP_Bool isCloned = false;
+#if ENABLE_CPP_DOM_MODEL
+    if(sUseNewCoreAPIs) {
+        isCloned = true;
+		try {
+			const XMPMeta2 & temp = dynamic_cast< const XMPMeta2 & >( thiz );
+			xClone = new XMPMeta2;
+		}
+        catch ( ... ) {
+			xClone = new XMPMeta;
+		}
+     }
+#endif
+    if(!isCloned) {
+       xClone = new XMPMeta;
+    }
+
+
 		thiz.Clone ( xClone, options );
 		XMP_Assert ( xClone->clientRefs == 0 );	// ! Gets incremented in TXMPMeta::Clone.
 		wResult->ptrResult = xClone;
-		
+
+	XMP_EXIT
+}
+
+void
+WXMPMeta_GetIXMPMetadata_1(XMPMetaRef	  xmpObjRef,
+								  WXMP_Result *  wResult )
+{
+	XMP_ENTER_ObjRead( XMPMeta, "WXMPMeta_GetIXMPMetadata_1" )
+    XMP_Bool haveResult = false;
+#if ENABLE_CPP_DOM_MODEL
+    if(sUseNewCoreAPIs){
+        haveResult = true;
+		try {
+			const XMPMeta2 & temp = dynamic_cast< const XMPMeta2 & >( thiz );
+			auto ptr = temp.mDOM.get();
+			wResult->ptrResult = ptr;
+		} catch ( ... ) {
+			wResult->ptrResult = NULL;
+			wResult->SetErrMessage("Not Available");
+		}
+    }
+#endif
+    if(!haveResult) {
+        wResult->ptrResult = NULL;
+        wResult->SetErrMessage("Not Available");
+    }
+
 	XMP_EXIT
 }
 
@@ -1083,20 +1118,6 @@ WXMPMeta_GetObjectOptions_1 ( XMPMetaRef    xmpObjRef,
 
 // -------------------------------------------------------------------------------------------------
 
-void
-WXMPMeta_SetObjectOptions_1 ( XMPMetaRef	 xmpObjRef,
-							  XMP_OptionBits options,
-							  WXMP_Result *	 wResult )
-{
-	XMP_ENTER_ObjWrite ( XMPMeta, "WXMPMeta_SetObjectOptions_1" )
-	
-		thiz->SetObjectOptions ( options );
-		
-	XMP_EXIT
-}
-
-// -------------------------------------------------------------------------------------------------
-
 void
 WXMPMeta_ParseFromBuffer_1 ( XMPMetaRef		xmpObjRef,
 							 XMP_StringPtr	buffer,
@@ -1132,7 +1153,7 @@ WXMPMeta_SerializeToBuffer_1 ( XMPMetaRef	  xmpObjRef,
 		if ( indent == 0 ) indent = "";
 		
 		thiz.SerializeToBuffer ( &localStr, options, padding, newline, indent, baseIndent );
-		if ( pktString != 0 ) (*SetClientString) ( pktString, localStr.c_str(), localStr.size() );
+		if ( pktString != 0 ) (*SetClientString) ( pktString, localStr.c_str(), static_cast< XMP_StringLen >( localStr.size() ) );
 
 	XMP_EXIT
 }
@@ -1184,8 +1205,19 @@ WXMPMeta_ResetErrorCallbackLimit_1 ( XMPMetaRef    xmpObjRef,
 	XMP_EXIT
 }
 
-// =================================================================================================
+void WXMPMeta_Use_CPP_DOM_APIs_1(XMP_Bool useNewCoreAPIs,
+				 WXMP_Result * /*wResult*/ )
+{
+#if ENABLE_CPP_DOM_MODEL
+	XMP_ENTER_Static ( "WXMPMeta_Use_CPP_DOM_APIs_1" )
+		sUseNewCoreAPIs = useNewCoreAPIs;
+	XMP_EXIT
+#else
+	IgnoreParam(useNewCoreAPIs);
+#endif
 
+}
+// =================================================================================================
 #if __cplusplus
 } /* extern "C" */
 #endif
