@@ -137,7 +137,7 @@ static void InternalMakeClipFilePath ( std::string * path,
 // ! also made sure that for a logical clip path the rootPath is an existing folder, and that the
 // ! file exists for a full file path.
 
-bool P2_CheckFormat ( XMP_FileFormat format,
+bool P2_CheckFormat ( XMP_FileFormat /*format*/,
 					  const std::string & rootPath,
 					  const std::string & gpName,
 					  const std::string & parentName,
@@ -368,7 +368,7 @@ void P2_MetaHandler::SetXMPPropertyFromLegacyXML ( bool digestFound,
 // =================================================================================================
 // P2_MetaHandler::SetXMPPropertyFromLegacyXML
 // ===========================================
-void P2_MetaHandler::SetXMPPropertyFromLegacyXML ( bool digestFound,
+void P2_MetaHandler::SetXMPPropertyFromLegacyXML ( bool /*digestFound*/,
 												   XML_NodePtr legacyContext,
 												   XMP_StringPtr schemaNS,
 												   XMP_StringPtr propName,
@@ -718,6 +718,7 @@ void P2_MetaHandler::SetStartTimecodeFromLegacyXML ( XML_NodePtr legacyVideoCont
 				} else if ( p2FrameRate == "50p" ) {
 
 					dmTimeFormat = "50Timecode";
+					this->AdjustTimeCode( p2StartTimecode, false );
 
 				} else if ( ( p2FrameRate == "59.94p" ) && ( p2DropFrameFlag != 0 ) ) {
 
@@ -726,6 +727,7 @@ void P2_MetaHandler::SetStartTimecodeFromLegacyXML ( XML_NodePtr legacyVideoCont
 					} else if ( XMP_LitMatch ( p2DropFrameFlag, "false" ) ) {
 						dmTimeFormat = "5994NonDropTimecode";
 					}
+					this->AdjustTimeCode( p2StartTimecode, false );
 
 				} else if ( (p2FrameRate == "59.94i") || (p2FrameRate == "29.97p") ) {
 
@@ -767,6 +769,56 @@ void P2_MetaHandler::SetStartTimecodeFromLegacyXML ( XML_NodePtr legacyVideoCont
 
 }	// P2_MetaHandler::SetStartTimecodeFromLegacyXML
 
+// =================================================================================================
+// P2_MetaHandler::AdjustTimeCode
+// ===========================================
+
+void P2_MetaHandler::AdjustTimeCode( std::string & p2Timecode, const XMP_Bool & isXMPtoXMLConversion )
+{
+	/*
+		XMP is storing frame number for 50P and 59.94P as [0-49] and [0-59] respectively,
+		but NRT XML can store frame number for these format as [0-29].
+		So, XMP need to adjust values for these cases.
+	*/
+	try
+	{
+		XMP_Int64 strLength = p2Timecode.length();
+		XMP_Int64 index = strLength - 1;
+		for (; index > 0; --index)
+			if (p2Timecode.at(index) == ':')
+				break;
+		std::string FFValue;
+		if ( index == strLength - 2 )								// HH:MM:SS:F
+			FFValue = p2Timecode.substr(index + 1, 1);
+		else if ( index == strLength - 3 )
+			FFValue = p2Timecode.substr(index + 1, 2);				// HH:MM:SS:FF
+		else
+			throw;													// Invalid format
+		stringstream timeCodeStream (FFValue);
+		XMP_Uns32 frameNumber;
+		timeCodeStream >> frameNumber;
+		if (isXMPtoXMLConversion)									// Conversion from XMP to XML so doing half the value
+		{
+			frameNumber /= 2;
+			XMP_Assert(frameNumber >= 0 && frameNumber < 30);
+		}
+		else														// Conversion from XML to XMP so doubling the value
+		{							
+			XMP_Assert(frameNumber >= 0 && frameNumber < 30);
+			frameNumber *= 2;
+		}
+		timeCodeStream.clear();
+		timeCodeStream << p2Timecode.substr(0, index + 1);
+		if (frameNumber < 10)
+			timeCodeStream << '0';
+		timeCodeStream << frameNumber;
+		p2Timecode = timeCodeStream.str();
+	}
+	catch (...)
+	{
+		XMP_Throw("P2 Invalid Timecode.", kXMPErr_InternalFailure);
+	}
+}	// P2_MetaHandler::AdjustTimeCode
 
 // =================================================================================================
 // P2_MetaHandler::SetGPSPropertyFromLegacyXML
@@ -1051,7 +1103,7 @@ void P2_MetaHandler::CacheFileData()
 	this->xmpPacket.erase();
 	this->xmpPacket.append ( (size_t)xmpLen, ' ' );
 
-	XMP_Int32 ioCount = xmpFile->ReadAll ( (void*)this->xmpPacket.data(), (XMP_Int32)xmpLen );
+	/*XMP_Int32 ioCount =*/ xmpFile->ReadAll ( (void*)this->xmpPacket.data(), (XMP_Int32)xmpLen );
 
 	this->packetInfo.offset = 0;
 	this->packetInfo.length = (XMP_Int32)xmpLen;
@@ -1235,7 +1287,35 @@ void P2_MetaHandler::UpdateFile ( bool doSafeUpdate )
 					updateLegacyXML = true;
 				}
 			}
+		}
 
+		// Half the startTimeCode frame number value in XML if require so
+		std::string xmpStartTimeCode;
+		bool isTimecodeExists = this->xmpObj.GetStructField(kXMP_NS_DM, "startTimecode", kXMP_NS_DM, "timeValue", &xmpStartTimeCode, 0);
+		if (isTimecodeExists)
+		{
+			std::string frameFormat;
+			this->xmpObj.GetStructField(kXMP_NS_DM, "startTimecode", kXMP_NS_DM, "timeFormat", &frameFormat, 0);
+			if (frameFormat == "50Timecode" || frameFormat == "5994DropTimecode" || frameFormat == "5994NonDropTimecode")
+			{
+				p2Clip = this->p2ClipManager.GetManagedClip();
+				XMP_StringPtr p2NS = p2Clip->GetP2RootNode()->ns.c_str();
+				XML_NodePtr legacyVideoContext = p2Clip->GetEssenceListNode();
+				if (legacyVideoContext != 0)
+				{
+					legacyVideoContext = legacyVideoContext->GetNamedElement(p2NS, "Video");
+					XML_NodePtr legacyProp = legacyVideoContext->GetNamedElement(p2NS, "StartTimecode");
+					if ((legacyProp != 0) && legacyProp->IsLeafContentNode())
+					{
+						AdjustTimeCode( xmpStartTimeCode, true );
+						if (xmpStartTimeCode != legacyProp->GetLeafContentValue())
+						{
+							legacyProp->SetLeafContentValue(xmpStartTimeCode.c_str());
+							updateLegacyXML = true;
+						}
+					}
+				}
+			}
 		}
 
 		std::string newDigest;
@@ -1302,7 +1382,7 @@ void P2_MetaHandler::UpdateFile ( bool doSafeUpdate )
 // P2_MetaHandler::WriteTempFile
 // =============================
 
-void P2_MetaHandler::WriteTempFile ( XMP_IO* tempRef )
+void P2_MetaHandler::WriteTempFile ( XMP_IO* /*tempRef*/ )
 {
 
 	// ! WriteTempFile is not supposed to be called for handlers that own the file.
