@@ -52,21 +52,20 @@ Chunk* getChunk ( ContainerChunk* parent, RIFF_MetaHandler* handler )
 		return new ContainerChunk( parent, handler );
 	case kChunk_LIST:
 		{
-		if ( level != 1 ) break; // only care on this level
+			if ( level != 1 ) break; // only care on this level
 
 			// look further (beyond 4+4 = beyond id+size) to check on relevance
 			file->Seek ( 8, kXMP_SeekFromCurrent  );
 			XMP_Uns32 containerType = XIO::PeekUns32_LE ( file );
 			file->Seek ( -8, kXMP_SeekFromCurrent  );
 
-		bool isRelevantList = ( containerType== kType_INFO || containerType == kType_Tdat );
-		if ( !isRelevantList ) break;
-
-				return new ContainerChunk( parent, handler );
+			bool isRelevantList = ( containerType== kType_INFO || containerType == kType_Tdat || containerType == kType_hdrl );
+			if ( !isRelevantList ) break;
+			return new ContainerChunk( parent, handler );
 		}
 	case kChunk_XMP:
-		if ( level != 1 ) break; // ignore on inappropriate levels (might be compound metadata?)
-		return new XMPChunk( parent, handler );
+			if ( level != 1 ) break; // ignore on inappropriate levels (might be compound metadata?)
+			return new XMPChunk( parent, handler );
 	case kChunk_DISP:
 		{
 			if ( level != 1 ) break; // only care on this level
@@ -114,6 +113,13 @@ Chunk* getChunk ( ContainerChunk* parent, RIFF_MetaHandler* handler )
 			JunkChunk* r = new JunkChunk( parent, handler );
 			return r;
 		}
+	case kChunk_IDIT:
+		{
+			if ( level != 2 ) break; // only care on this level
+			ValueChunk* r = new ValueChunk( parent, handler );
+			handler->iditChunk = r;
+			return r;
+		}
 	}
 	// this "default:" section must be ouside switch bracket, to be
 	// reachable by all those break statements above:
@@ -135,12 +141,12 @@ Chunk* getChunk ( ContainerChunk* parent, RIFF_MetaHandler* handler )
 
 // BASE CLASS CHUNK ///////////////////////////////////////////////
 // ad hoc creation
-Chunk::Chunk( ContainerChunk* parent, ChunkType c, XMP_Uns32 id )
+Chunk::Chunk( ContainerChunk* parent_, ChunkType c, XMP_Uns32 id_ )
 {
 	this->hasChange = false;
 	this->chunkType = c; // base class assumption
-	this->parent = parent;
-	this->id = id;
+	this->parent = parent_;
+	this->id = id_;
 	this->oldSize = 0;
 	this->newSize = 8;
 	this->oldPos = 0; // inevitable for ad-hoc
@@ -156,10 +162,10 @@ Chunk::Chunk( ContainerChunk* parent, ChunkType c, XMP_Uns32 id )
 }
 
 // parsing creation
-Chunk::Chunk( ContainerChunk* parent, RIFF_MetaHandler* handler, bool skip, ChunkType c )
+Chunk::Chunk( ContainerChunk* parent_, RIFF_MetaHandler* handler, bool skip, ChunkType c )
 {
 	chunkType = c; // base class assumption
-	this->parent = parent;
+	this->parent = parent_;
 	this->oldSize = 0;
 	this->hasChange = false; // [2414649] valid assumption at creation time
 
@@ -173,11 +179,11 @@ Chunk::Chunk( ContainerChunk* parent, RIFF_MetaHandler* handler, bool skip, Chun
 	// Make sure the size is within expected bounds.
 	XMP_Int64 chunkEnd = this->oldPos + this->oldSize;
 	XMP_Int64 chunkLimit = handler->oldFileSize;
-	if ( parent != 0 ) chunkLimit = parent->oldPos + parent->oldSize;
+	if ( parent_ != 0 ) chunkLimit = parent_->oldPos + parent_->oldSize;
 	if ( chunkEnd > chunkLimit ) {
 		bool isUpdate = XMP_OptionIsSet ( handler->parent->openFlags, kXMPFiles_OpenForUpdate );
 		bool repairFile = XMP_OptionIsSet ( handler->parent->openFlags, kXMPFiles_OpenRepairFile );
-		if ( (! isUpdate) || (repairFile && (parent == 0)) ) {
+		if ( (! isUpdate) || (repairFile && (parent_ == 0)) ) {
 			this->oldSize = chunkLimit - this->oldPos;
 		} else {
 			XMP_Throw ( "Bad RIFF chunk size", kXMPErr_BadFileFormat );
@@ -198,7 +204,7 @@ Chunk::Chunk( ContainerChunk* parent, RIFF_MetaHandler* handler, bool skip, Chun
 	}
 }
 
-void Chunk::changesAndSize( RIFF_MetaHandler* handler )
+void Chunk::changesAndSize( RIFF_MetaHandler* /*handler*/ )
 {
 	// only unknown chunks should reach this method,
 	// all others must reach overloads, hence little to do here:
@@ -206,18 +212,19 @@ void Chunk::changesAndSize( RIFF_MetaHandler* handler )
 	this->newSize = this->oldSize;
 }
 
-std::string Chunk::toString(XMP_Uns8 level )
+std::string Chunk::toString(XMP_Uns8 /*level*/)
 {
 	char buffer[256];
 	snprintf( buffer, 255, "%.4s -- "
 							"oldSize: 0x%.8llX,  "
 							"newSize: 0x%.8llX,  "
 							"oldPos: 0x%.8llX\n",
-		(char*)(&this->id), this->oldSize, this->newSize, this->oldPos );
+                  (char*)(&this->id), (long long unsigned)this->oldSize,
+                  (long long unsigned)this->newSize, (long long unsigned)this->oldPos );
 	return std::string(buffer);
 }
 
-void Chunk::write( RIFF_MetaHandler* handler, XMP_IO* file , bool isMainChunk )
+void Chunk::write( RIFF_MetaHandler* /*handler*/, XMP_IO* /*file*/, bool /*isMainChunk*/ )
 {
 	throw new XMP_Error(kXMPErr_InternalFailure, "Chunk::write never to be called for unknown chunks.");
 }
@@ -230,16 +237,16 @@ Chunk::~Chunk()
 // CONTAINER CHUNK /////////////////////////////////////////////////
 // a) creation
 // [2376832] expectedSize - minimum padding "parking size" to use, if not available append to end
-ContainerChunk::ContainerChunk( ContainerChunk* parent, XMP_Uns32 id, XMP_Uns32 containerType ) : Chunk( NULL /* !! */, chunk_CONTAINER, id )
+ContainerChunk::ContainerChunk( ContainerChunk* parent_, XMP_Uns32 id_, XMP_Uns32 containerType ) : Chunk( NULL /* !! */, chunk_CONTAINER, id_ )
 {
 	// accept no unparented ConatinerChunks
-	XMP_Enforce( parent != NULL );
+	XMP_Enforce( parent_ != NULL );
 
 	this->containerType = containerType;
 	this->newSize = 12;
-	this->parent = parent;
+	this->parent = parent_;
 
-	chunkVect* siblings = &parent->children;
+	chunkVect* siblings = &parent_->children;
 
 	// add at end. ( oldSize==0 will flag optimization later in the process)
 	siblings->push_back( this );
@@ -268,7 +275,8 @@ ContainerChunk::ContainerChunk( ContainerChunk* parent, RIFF_MetaHandler* handle
 		// has *relevant* subChunks? (there might be e.g. non-INFO LIST chunks we don't care about)
 		bool hasSubChunks = ( ( this->id == kChunk_RIFF ) ||
 							  ( this->id == kChunk_LIST && this->containerType == kType_INFO ) ||
-							  ( this->id == kChunk_LIST && this->containerType == kType_Tdat )
+							  ( this->id == kChunk_LIST && this->containerType == kType_Tdat ) ||
+							  ( this->id == kChunk_LIST && this->containerType == kType_hdrl )
 						  );
 		XMP_Int64 endOfChunk = this->oldPos + this->oldSize;
 
@@ -331,6 +339,8 @@ ContainerChunk::ContainerChunk( ContainerChunk* parent, RIFF_MetaHandler* handle
 				handler->listInfoChunk = this;
 			if ( level==1 && this->id==kChunk_LIST && this->containerType == kType_Tdat )
 				handler->listTdatChunk = this;
+			if ( level == 1 && this->id == kChunk_LIST && this->containerType == kType_hdrl )
+				handler->listHdlrChunk = this;
 		}
 		else // skip non-interest container chunk
 		{
@@ -587,14 +597,17 @@ std::string ContainerChunk::toString(XMP_Uns8 level )
 	XMP_Int64 offset= 12; // compute offsets, just for informational purposes
 	// (actually only correct for first chunk)
 
-	char buffer[256];
-	snprintf( buffer, 255, "%.4s:%.4s, "
+	char buffer0[256];
+	snprintf( buffer0, 255, "%.4s:%.4s, "
 			"oldSize: 0x%8llX, "
 			"newSize: 0x%.8llX, "
 			"oldPos: 0x%.8llX\n",
-			(char*)(&this->id), (char*)(&this->containerType), this->oldSize, this->newSize, this->oldPos );
+			(char*)(&this->id), (char*)(&this->containerType),
+                  (long long unsigned)this->oldSize,
+                  (long long unsigned)this->newSize,
+                  (long long unsigned)this->oldPos );
 
-	std::string r(buffer);
+	std::string r(buffer0);
 	chunkVectIter iter;
 	for( iter = this->children.begin(); iter != this->children.end(); iter++ )
 	{
@@ -678,17 +691,17 @@ ContainerChunk::~ContainerChunk()
 // a) create
 
 // a) creation
-XMPChunk::XMPChunk( ContainerChunk* parent ) : Chunk( parent, chunk_XMP , kChunk_XMP )
+XMPChunk::XMPChunk( ContainerChunk* parent_ ) : Chunk( parent_, chunk_XMP , kChunk_XMP )
 {
 	// nothing
 }
 
 // b) parse
-XMPChunk::XMPChunk( ContainerChunk* parent, RIFF_MetaHandler* handler ) : Chunk( parent, handler, false, chunk_XMP )
+XMPChunk::XMPChunk( ContainerChunk* parent_, RIFF_MetaHandler* handler ) : Chunk( parent_, handler, false, chunk_XMP )
 {
 	chunkType = chunk_XMP;
 	XMP_IO* file = handler->parent->ioRef;
-	XMP_Uns8 level = handler->level;
+	/*XMP_Uns8 level = handler->level*/;
 
 	handler->packetInfo.offset = this->oldPos + 8;
 	handler->packetInfo.length = (XMP_Int32) this->oldSize - 8;
@@ -715,7 +728,7 @@ void XMPChunk::changesAndSize( RIFF_MetaHandler* handler )
 	this->hasChange = true;
 }
 
-void XMPChunk::write( RIFF_MetaHandler* handler, XMP_IO* file, bool isMainChunk )
+void XMPChunk::write( RIFF_MetaHandler* handler, XMP_IO* file, bool /*isMainChunk*/ )
 {
 	XIO::WriteUns32_LE( file, kChunk_XMP );
 	XIO::WriteUns32_LE( file, (XMP_Uns32) this->newSize - 8 ); // validated in changesAndSize() above
@@ -724,18 +737,18 @@ void XMPChunk::write( RIFF_MetaHandler* handler, XMP_IO* file, bool isMainChunk
 
 // Value CHUNK ///////////////////////////////////////////////
 // a) creation
-ValueChunk::ValueChunk( ContainerChunk* parent, std::string value, XMP_Uns32 id ) : Chunk( parent, chunk_VALUE, id )
+ValueChunk::ValueChunk( ContainerChunk* parent_, std::string value, XMP_Uns32 id_ ) : Chunk( parent_, chunk_VALUE, id_ )
 {
 	this->oldValue = std::string();
 	this->SetValue( value );
 }
 
 // b) parsing
-ValueChunk::ValueChunk( ContainerChunk* parent, RIFF_MetaHandler* handler ) : Chunk( parent, handler, false, chunk_VALUE )
+ValueChunk::ValueChunk( ContainerChunk* parent_, RIFF_MetaHandler* handler ) : Chunk( parent_, handler, false, chunk_VALUE )
 {
 	// set value: -----------------
 	XMP_IO* file = handler->parent->ioRef;
-	XMP_Uns8 level = handler->level;
+	/*XMP_Uns8 level = handler->level;*/
 
 	// unless changed through reconciliation, assume for now.
 	// IMPORTANT to stay true to the original (no \0 cleanup or similar)
@@ -761,7 +774,7 @@ void ValueChunk::SetValue( std::string value, bool optionalNUL /* = false */ )
 	this->newSize = this->newValue.size() + 8;
 }
 
-void ValueChunk::changesAndSize( RIFF_MetaHandler* handler )
+void ValueChunk::changesAndSize( RIFF_MetaHandler* /*handler*/ )
 {
 	// Don't simply assign to this->hasChange, it might already be true.
 	if ( this->newValue.size() != this->oldValue.size() ) {
@@ -771,7 +784,7 @@ void ValueChunk::changesAndSize( RIFF_MetaHandler* handler )
 	}
 }
 
-void ValueChunk::write( RIFF_MetaHandler* handler, XMP_IO* file, bool isMainChunk )
+void ValueChunk::write( RIFF_MetaHandler* /*handler*/, XMP_IO* file, bool /*isMainChunk*/ )
 {
 	XIO::WriteUns32_LE( file, this->id );
 	XIO::WriteUns32_LE( file, (XMP_Uns32)this->newSize - 8 );
@@ -780,10 +793,10 @@ void ValueChunk::write( RIFF_MetaHandler* handler, XMP_IO* file, bool isMainChun
 
 /* remove value chunk if existing.
    return true if it was existing. */
-bool ContainerChunk::removeValue( XMP_Uns32	id )
+bool ContainerChunk::removeValue( XMP_Uns32	id_ )
 {
 	valueMap* cm = &this->childmap;
-	valueMapIter iter = cm->find( id );
+	valueMapIter iter = cm->find( id_ );
 
 	if( iter == cm->end() )
 		return false;  //not found
@@ -795,7 +808,7 @@ bool ContainerChunk::removeValue( XMP_Uns32	id )
 	chunkVectIter cvIter;
 	for (cvIter = cv->begin(); cvIter != cv->end(); ++cvIter )
 	{
-		if ( (*cvIter)->id == id )
+		if ( (*cvIter)->id == id_ )
 			break; // found!
 	}
 	XMP_Validate( cvIter != cv->end(), "property not found in children vector", kXMPErr_InternalFailure );
@@ -815,8 +828,6 @@ chunkVectIter ContainerChunk::getChild( Chunk* needle )
 	chunkVectIter iter;
 	for( iter = this->children.begin(); iter != this->children.end(); iter++ )
 	{
-		Chunk* temp1 = *iter;
-		Chunk* temp2 = needle;
 		if ( (*iter) == needle ) return iter;
 	}
 	return this->children.end();
@@ -839,7 +850,7 @@ void ContainerChunk::replaceChildWithJunk( Chunk* child, bool deleteChild )
 
 // JunkChunk ///////////////////////////////////////////////////
 // a) creation
-JunkChunk::JunkChunk( ContainerChunk* parent, XMP_Int64 size ) : Chunk( parent, chunk_JUNK, kChunk_JUNK )
+JunkChunk::JunkChunk( ContainerChunk* parent_, XMP_Int64 size ) : Chunk( parent_, chunk_JUNK, kChunk_JUNK )
 {
 	XMP_Assert( size >= 8 );
 	this->oldSize = size;
@@ -848,12 +859,12 @@ JunkChunk::JunkChunk( ContainerChunk* parent, XMP_Int64 size ) : Chunk( parent,
 }
 
 // b) parsing
-JunkChunk::JunkChunk( ContainerChunk* parent, RIFF_MetaHandler* handler ) : Chunk( parent, handler, true, chunk_JUNK )
+JunkChunk::JunkChunk( ContainerChunk* parent_, RIFF_MetaHandler* handler ) : Chunk( parent_, handler, true, chunk_JUNK )
 {
 	chunkType = chunk_JUNK;
 }
 
-void JunkChunk::changesAndSize( RIFF_MetaHandler* handler )
+void JunkChunk::changesAndSize( RIFF_MetaHandler* /*handler*/ )
 {
 	this->newSize = this->oldSize; // optimization at a later stage
 	XMP_Validate( this->newSize <= 0xFFFFFFFFLL, "no single chunk may be above 4 GB", kXMPErr_InternalFailure );
@@ -864,7 +875,7 @@ void JunkChunk::changesAndSize( RIFF_MetaHandler* handler )
 const static XMP_Uns32 kZeroBufferSize64K = 64 * 1024;
 static XMP_Uns8 kZeroes64K [ kZeroBufferSize64K ]; // C semantics guarantee zero initialization.
 
-void JunkChunk::write( RIFF_MetaHandler* handler, XMP_IO* file, bool isMainChunk )
+void JunkChunk::write( RIFF_MetaHandler* /*handler*/, XMP_IO* file, bool /*isMainChunk*/ )
 {
 	XIO::WriteUns32_LE( file, kChunk_JUNK );		// write JUNK, never JUNQ
 	XMP_Enforce( this->newSize < 0xFFFFFFFF );
