@@ -92,7 +92,7 @@ void TIFF_FileWriter::DeleteExistingInfo()
 // TIFF_FileWriter::PickIFD
 // ========================
 
-XMP_Uns8 TIFF_FileWriter::PickIFD ( XMP_Uns8 ifd, XMP_Uns16 id )
+XMP_Uns8 TIFF_FileWriter::PickIFD ( XMP_Uns8 ifd, XMP_Uns16 /*id*/ )
 {
 	if ( ifd > kTIFF_LastRealIFD ) {
 		if ( ifd != kTIFF_KnownIFD ) XMP_Throw ( "Invalid IFD number", kXMPErr_BadParam );
@@ -571,7 +571,7 @@ bool TIFF_FileWriter::IsLegacyChanged()
 // TIFF_FileWriter::ParseMemoryStream
 // ==================================
 
-void TIFF_FileWriter::ParseMemoryStream ( const void* data, XMP_Uns32 length, bool copyData /* = true */ )
+void TIFF_FileWriter::ParseMemoryStream ( const void* data, XMP_Uns32 length, bool copyData /* = true */, bool /* isAlreadyLittle = false */ )
 {
 	this->DeleteExistingInfo();
 	this->memParsed = true;
@@ -677,23 +677,23 @@ XMP_Uns32 TIFF_FileWriter::ProcessMemoryIFD ( XMP_Uns32 ifdOffset, XMP_Uns8 ifd
 	}
 
 	XMP_Uns8* ifdPtr = this->memStream + ifdOffset;
-	XMP_Uns16 tagCount = this->GetUns16 ( ifdPtr );
+	XMP_Uns16 tagCount1 = this->GetUns16 ( ifdPtr );
 	RawIFDEntry* ifdEntries = (RawIFDEntry*)(ifdPtr+2);
 
-	if ( tagCount >= 0x8000 ) {
+	if ( tagCount1 >= 0x8000 ) {
 		XMP_Error error ( kXMPErr_BadTIFF, "Outrageous IFD count" );
 		this->NotifyClient ( kXMPErrSev_FileFatal, error );
 	}
 
-	if ( (XMP_Uns32)(2 + tagCount*12 + 4) > (this->tiffLength - ifdOffset) ) {
+	if ( (XMP_Uns32)(2 + tagCount1*12 + 4) > (this->tiffLength - ifdOffset) ) {
 		XMP_Error error ( kXMPErr_BadTIFF, "Out of bounds IFD" );
 		this->NotifyClient ( kXMPErrSev_FileFatal, error );
 	}
 
 	ifdInfo.origIFDOffset = ifdOffset;
-	ifdInfo.origCount  = tagCount;
+	ifdInfo.origCount  = tagCount1;
 
-	for ( size_t i = 0; i < tagCount; ++i ) {
+	for ( size_t i = 0; i < tagCount1; ++i ) {
 
 		RawIFDEntry* rawTag  = &ifdEntries[i];
 		XMP_Uns16    tagType = this->GetUns16 ( &rawTag->type );
@@ -731,9 +731,20 @@ XMP_Uns32 TIFF_FileWriter::ProcessMemoryIFD ( XMP_Uns32 ifdOffset, XMP_Uns8 ifd
 
 	}
 
-	ifdPtr += (2 + tagCount*12);
+	ifdPtr += (2 + tagCount1*12);
 	ifdInfo.origNextIFD = this->GetUns32 ( ifdPtr );
-
+// The following code modifies a file in case it is invalid, we should keep this fix so that we can track this issue if we receive client bugs for this
+#if 0
+	if (ifdInfo.origNextIFD != 0) {
+        if ( (ifdInfo.origNextIFD < 8) || (ifdInfo.origNextIFD > (this->tiffLength - kEmptyIFDLength)) ) {
+            // Next IFD offset is invalid.  Ignore it.
+            ifdInfo.origNextIFD = 0;
+            // Should we try to patch it?
+            ifdInfo.changed = true;
+            this->changed = true;
+        }
+	}
+#endif 
 	return ifdInfo.origNextIFD;
 
 }	// TIFF_FileWriter::ProcessMemoryIFD
@@ -780,13 +791,13 @@ void TIFF_FileWriter::ParseFileStream ( XMP_IO* fileRef )
 	}
 
 	const InternalTagInfo* exifIFDTag = this->FindTagInIFD ( kTIFF_PrimaryIFD, kTIFF_ExifIFDPointer );
-	if ( (exifIFDTag != 0) && (exifIFDTag->type == kTIFF_LongType) && (exifIFDTag->count == 1) ) {
+	if ( ( exifIFDTag != 0 ) && ( ( exifIFDTag->type == kTIFF_LongType || exifIFDTag->type == kTIFF_IFDType ) && ( exifIFDTag->count == 1 ) ) ) {
 		XMP_Uns32 exifOffset = this->GetUns32 ( exifIFDTag->dataPtr );
 		(void) this->ProcessFileIFD ( kTIFF_ExifIFD, exifOffset, fileRef );
 	}
 
 	const InternalTagInfo* gpsIFDTag = this->FindTagInIFD ( kTIFF_PrimaryIFD, kTIFF_GPSInfoIFDPointer );
-	if ( (gpsIFDTag != 0) && (gpsIFDTag->type == kTIFF_LongType) && (gpsIFDTag->count == 1) ) {
+	if ( ( gpsIFDTag != 0 ) && ( ( gpsIFDTag->type == kTIFF_LongType || gpsIFDTag->type == kTIFF_IFDType ) && ( gpsIFDTag->count == 1 ) ) ) {
 		XMP_Uns32 gpsOffset = this->GetUns32 ( gpsIFDTag->dataPtr );
 		if ( IsOffsetValid (gpsOffset, 8, ifdLimit ) ) {	// Remove a bad GPS IFD offset.
 			(void) this->ProcessFileIFD ( kTIFF_GPSInfoIFD, gpsOffset, fileRef );
@@ -798,7 +809,7 @@ void TIFF_FileWriter::ParseFileStream ( XMP_IO* fileRef )
 	}
 
 	const InternalTagInfo* interopIFDTag = this->FindTagInIFD ( kTIFF_ExifIFD, kTIFF_InteroperabilityIFDPointer );
-	if ( (interopIFDTag != 0) && (interopIFDTag->type == kTIFF_LongType) && (interopIFDTag->dataLen == 4) ) {
+	if ( ( interopIFDTag != 0 ) && ( ( interopIFDTag->type == kTIFF_LongType || interopIFDTag->type == kTIFF_IFDType ) && ( interopIFDTag->dataLen == 4 ) ) ) {
 		XMP_Uns32 interopOffset = this->GetUns32 ( interopIFDTag->dataPtr );
 		if ( IsOffsetValid (interopOffset, 8, ifdLimit ) ) {	// Remove a bad Interoperability IFD offset.
 			(void) this->ProcessFileIFD ( kTIFF_InteropIFD, interopOffset, fileRef );
@@ -854,10 +865,10 @@ XMP_Uns32 TIFF_FileWriter::ProcessFileIFD ( XMP_Uns8 ifd, XMP_Uns32 ifdOffset, X
 	if ( ! XIO::CheckFileSpace ( fileRef, 2 ) ) return 0;	// Bail for a truncated file.
 	fileRef->ReadAll ( intBuffer, 2 );
 
-	XMP_Uns16 tagCount = this->GetUns16 ( intBuffer );
-	if ( tagCount >= 0x8000 ) return 0;	// Maybe wrong byte order.
-	if ( ! XIO::CheckFileSpace ( fileRef, 12*tagCount ) ) return 0;	// Bail for a truncated file.
-	fileRef->ReadAll ( &ifdBuffer[0], 12*tagCount );
+	XMP_Uns16 tagCount1 = this->GetUns16 ( intBuffer );
+	if ( tagCount1 >= 0x8000 ) return 0;	// Maybe wrong byte order.
+	if ( ! XIO::CheckFileSpace ( fileRef, 12*tagCount1 ) ) return 0;	// Bail for a truncated file.
+	fileRef->ReadAll ( &ifdBuffer[0], 12*tagCount1 );
 
 	if ( ! XIO::CheckFileSpace ( fileRef, 4 ) ) {
         ifdInfo.origNextIFD = 0;	// Tolerate a trncated file, do the remaining processing.
@@ -867,7 +878,7 @@ XMP_Uns32 TIFF_FileWriter::ProcessFileIFD ( XMP_Uns8 ifd, XMP_Uns32 ifdOffset, X
 	}
 
 	ifdInfo.origIFDOffset = ifdOffset;
-	ifdInfo.origCount  = tagCount;
+	ifdInfo.origCount  = tagCount1;
 
 	// ---------------------------------------------------------------------------------------------
 	// First create all of the IFD map entries, capturing short values, and get the next IFD offset.
@@ -877,7 +888,7 @@ XMP_Uns32 TIFF_FileWriter::ProcessFileIFD ( XMP_Uns8 ifd, XMP_Uns32 ifdOffset, X
 
 	XMP_Uns8* ifdPtr = &ifdBuffer[0];	// Move to the first IFD entry.
 
-	for ( XMP_Uns16 i = 0; i < tagCount; ++i, ifdPtr += 12 ) {
+	for ( XMP_Uns16 i = 0; i < tagCount1; ++i, ifdPtr += 12 ) {
 
 		RawIFDEntry* rawTag = (RawIFDEntry*)ifdPtr;
 		XMP_Uns16    tagType = this->GetUns16 ( &rawTag->type );
@@ -1026,7 +1037,7 @@ static bool FlipCFATable ( void* voidPtr, XMP_Uns32 tagLen, GetUns16_Proc GetUns
 
 // ! The Exif 2.2 description is a bit garbled. It might be wrong. It would be nice to have a real example.
 
-static bool FlipDSDTable ( void* voidPtr, XMP_Uns32 tagLen, GetUns16_Proc GetUns16 )
+static bool FlipDSDTable ( void* voidPtr, XMP_Uns32 tagLen, GetUns16_Proc /*GetUns16*/ )
 {
 	if ( tagLen < 4 ) return false;
 
@@ -1919,7 +1930,10 @@ void TIFF_FileWriter::UpdateFileStream ( XMP_IO* fileRef, XMP_ProgressTracker* p
 
 	// Append the IFDs and tag values that grow.
 
-	XMP_Int64 fileEnd = fileRef->Seek ( 0, kXMP_SeekFromEnd  );
+#if XMP_DebugBuild
+	XMP_Int64 fileEnd =
+#endif
+		fileRef->Seek ( 0, kXMP_SeekFromEnd  );
 	XMP_Assert ( fileEnd == appendedOrigin );
 
 	for ( int ifd = 0; ifd < kTIFF_KnownIFDCount; ++ifd ) {
