@@ -33,7 +33,7 @@ struct FileHandlerPair
 };
 
 // =================================================================================================
-
+#if 0 // unused
 static XMP_FileFormat GetXMPFileFormatFromFilePath( XMP_StringPtr filePath )
 {
 	XMP_StringPtr pathName = filePath + strlen(filePath);
@@ -44,7 +44,7 @@ static XMP_FileFormat GetXMPFileFormatFromFilePath( XMP_StringPtr filePath )
 	XMP_StringPtr fileExt = pathName + 1;
 	return HandlerRegistry::getInstance().getFileFormat ( fileExt );
 }
-
+#endif
 // =================================================================================================
 
 static XMPFileHandler* Plugin_MetaHandlerCTor ( FileHandlerSharedPtr handler, XMPFiles* parent )
@@ -56,8 +56,11 @@ static XMPFileHandler* Plugin_MetaHandlerCTor ( FileHandlerSharedPtr handler, XM
 	{
 		XMP_Throw ( "Plugin not loaded", kXMPErr_InternalFailure );
 	}
-
-	handler->getModule()->getPluginAPIs()->mInitializeSessionProc ( handler->getUID().c_str(), parent->GetFilePath().c_str(), (XMP_Uns32)parent->format, (XMP_Uns32)handler->getHandlerFlags(), (XMP_Uns32)parent->openFlags, &object, &error );
+	
+	if( handler->getModule()->getPluginAPIs()->mInitializeSessionV2Proc )
+		handler->getModule()->getPluginAPIs()->mInitializeSessionV2Proc ( handler->getUID().c_str(), parent->GetFilePath().c_str(), (XMP_Uns32)parent->format, (XMP_Uns32)handler->getHandlerFlags(), (XMP_Uns32)parent->openFlags, &object, &error, ErrorCallbackBox( parent->errorCallback.wrapperProc, parent->errorCallback.clientProc, parent->errorCallback.context, parent->errorCallback.limit ), parent->progressTracker->GetCallbackInfo() );
+	else
+		handler->getModule()->getPluginAPIs()->mInitializeSessionProc ( handler->getUID().c_str(), parent->GetFilePath().c_str(), (XMP_Uns32)parent->format, (XMP_Uns32)handler->getHandlerFlags(), (XMP_Uns32)parent->openFlags, &object, &error );
 	CheckError ( error );
 
 	FileHandlerInstance* instance = new FileHandlerInstance ( object, handler, parent );
@@ -80,7 +83,7 @@ static XMPFileHandler* Plugin_MetaHandlerCTor_Replacement( XMPFiles * parent )
 
 // =================================================================================================
 
-static bool Plugin_CheckFileFormat ( FileHandlerSharedPtr handler, XMP_StringPtr filePath, XMP_IO * fileRef, XMPFiles * parent )
+static bool Plugin_CheckFileFormat ( FileHandlerSharedPtr handler, XMP_StringPtr filePath, XMP_IO * fileRef, XMPFiles * /*parent*/ )
 {
 	if ( handler != 0 ) {
 
@@ -183,7 +186,7 @@ static bool Plugin_CheckFolderFormat( FileHandlerSharedPtr handler,
 									  const std::string & gpName,
 									  const std::string & parentName,
 									  const std::string & leafName,
-									  XMPFiles * parent )
+									  XMPFiles * /*parent*/ )
 {
 	XMP_Bool result = false;
 
@@ -237,16 +240,16 @@ PluginManager::PluginManager( const std::string& pluginDir, const std::string& p
 		mExtensions.push_back ( std::string ( kLibraryExtensions[i] ) );
 	}
 
-	size_t pos = std::string::npos;
+	size_t pos1 = std::string::npos;
 
 	#if XMP_WinBuild
 		// convert to Win kDirChar
-		while ( (pos = mPluginDir.find ('/')) != string::npos ) {
-			mPluginDir.replace (pos, 1, "\\");
+		while ( (pos1 = mPluginDir.find ('/')) != string::npos ) {
+			mPluginDir.replace (pos1, 1, "\\");
 		}
 	#else
-		while ( (pos = mPluginDir.find ('\\')) != string::npos ) {
-			mPluginDir.replace (pos, 1, "/");
+		while ( (pos1 = mPluginDir.find ('\\')) != string::npos ) {
+			mPluginDir.replace (pos1, 1, "/");
 		}
 	#endif
 
@@ -318,7 +321,7 @@ static bool registerHandler( XMP_FileFormat format, FileHandlerSharedPtr handler
 	bool ret = false;
 
 	HandlerRegistry& hdlrReg				= HandlerRegistry::getInstance();
-	FileHandlerType type					= handler->getHandlerType();
+	/*FileHandlerType type					=*/ handler->getHandlerType();
 	CheckFileFormatProc chkFileFormat		= NULL;
 	CheckFolderFormatProc chkFolderFormat	= NULL;
 	XMPFileHandlerCTor hdlCtor				= NULL;
